@@ -2,7 +2,7 @@
 from moviepy.editor import *
 from moviepy.video.fx import loop, mask_color, crop
 from bgeditor.common import utils
-from bgeditor.common.utils import cache_file, download_file, upload_file, upload_static_file
+from bgeditor.common.utils import cache_file, download_file, upload_file, upload_static_file, upload_file_resource
 from bgeditor.dao.LyricVer2 import LyricVer2
 from bgeditor.dao.Matrix import Matrix
 from bgeditor.dao import MusicHelper
@@ -612,7 +612,7 @@ class VideoComp(Component):
                     if path_loop is None:
                         raise Exception(" Error create source loop")
                     else:
-                        drive_id = upload_file(path_loop)
+                        drive_id = upload_file_resource(path_loop)
                     requests.get(self.mf_server+"resource/set-md5/"+self.kind+"/" + self.md5+"/"+ drive_id)
                     self.video_path = path_loop
         else:
